SHA3Internal

Struct SHA3Internal 

pub struct SHA3Internal<PARAMS: SHA3Params> { /* private fields */ }
Internal struct for SHA3. This uses a private bound so that you cannot instantiate it directly and have to use the provided and NIST-approved parameters.

Implementations

Source

impl<PARAMS: SHA3Params> SHA3Internal<PARAMS>

pub fn new() -> Self

Get a new SHA3 instance, ready for use.