pub struct SHA3Internal<PARAMS: SHA3Params> { /* private fields */ }Expand description
Internal struct for SHA3. This uses a private bound so that you cannot instantiate it directly and have to use the provided and NIST-approved parameters.
Implementations
Sourceimpl<PARAMS: SHA3Params> SHA3Internal<PARAMS>
impl<PARAMS: SHA3Params> SHA3Internal<PARAMS>